/*
  This file will fix some legacy widget styles that aren't styled in libadwaita
*/

@define-color accent_bg_color @blue_3;
@define-color accent_fg_color white;

/* add a bg color to notebook headers */
notebook > header {
  background-color: @headerbar_bg_color;
  border-color: mix(currentColor,@window_bg_color,0.85);
}

:root {
  --accent-blue: #3584e4;
  --accent-teal: #2190a4;
  --accent-green: #3a944a;
  --accent-yellow: #c88800;
  --accent-orange: #ed5b00;
  --accent-red: #e62d42;
  --accent-pink: #d56199;
  --accent-purple: #9141ac;
  --accent-slate: #6f8396;

  --accent-color: var(--accent-bg-color);
  --accent-bg-color: var(--accent-blue);
  --accent-fg-color: @accent_fg_color;

  --card-bg-color: @card_bg_color;
}

/* Chromium */
.background.chromium {
  background-color: color-mix(in srgb, currentColor 5%, @headerbar_bg_color);
}

.background.chromium windowcontrols > button {
  background-color: color-mix(in srgb, currentColor 10%, transparent);
  min-width: 24px;
  padding: 0;
  box-shadow: none;
  margin: 0 4px; /* doesn't work on the far edges of the header-bar */
}

.background.chromium windowcontrols > button {
  background-color: color-mix(in srgb, currentColor 10%, transparent);
  border-radius: 100%;
  transition: background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.background.chromium windowcontrols > button:hover {
  background-color: color-mix(in srgb, currentColor 15%, transparent);
}

.background.chromium windowcontrols > button:active {
  background-color: color-mix(in srgb, currentColor 30%, transparent);
}

